@@ -352,7 +352,10 @@ class ShapeOp(UnaryUnaryOp):#{{{
 class FilterOp(UnaryUnaryOp):#{{{
     __slots__ = ["constraint","has_missing"]
 
-    def __init__(self,slice,constraint, ndim):
+    def __init__(self,slice,constraint, ndim,refconstraint=None):
+        if refconstraint is None:
+            refconstraint = constraint
+
         stype = slice.type
         assert isinstance(stype, rtypes.TypeArray), "Filter on non-array type not possible"
         
@@ -364,7 +367,7 @@ class FilterOp(UnaryUnaryOp):#{{{
 
         sdims = stype.dims
         if(ndim is None):
-            sdims, subtype = sdims.removeDim(0, constraint, stype.subtypes[0])
+            sdims, subtype = sdims.removeDim(0, refconstraint, stype.subtypes[0])
         else:
             sdims, subtype = sdims.updateDim(0, ndim, stype.subtypes[0])
         
@@ -419,7 +422,7 @@ def filter(slice,constraint,seldimpath, ndim, mode="dim"):#{{{
             xndim = ndim.changeDependent(tuple(ndep), slice.dims)
         else:
             xndim = ndim
-        slice = FilterOp(slice,tconstraint,xndim)
+        slice = FilterOp(slice,tconstraint,xndim,constraint)
 
         #adapt used_dims
         used_dims = dimpaths.applyPlan(used_dims,splan,newvalue=True,copyvalue=True,ensurevalue=True, existvalue=True)
@@ -640,16 +643,23 @@ class PackIndexDictOp(MultiUnaryOp):#{{{
 
 
 class TakeOp(MultiUnaryOp):
-    __slots__ = ['allow_missing']
-    def __init__(self, source_slice, take_slice, allow_missing=False):
+    __slots__ = ['allow_missing','keep_missing']
+    def __init__(self, source_slice, take_slice, allow_missing=False, keep_missing=False):
         assert isinstance(source_slice.type, rtypes.TypeIndexDict), "Take left op should have type index dict"
         source_slice, take_slice = broadcast((source_slice, take_slice), mode="dim")[0]
         ntype = source_slice.type.subtypes[1].subtypes[0]
         if allow_missing:
             ntype = ntype.setHasMissing(True)
-        name = source_slice.type.fieldnames[1]
+        elif keep_missing:
+            ntype = casts.castImplicitCommonType(ntype,take_slice.type)
+
+        if keep_missing:
+            name = take_slice.name
+        else:
+            name = source_slice.type.fieldnames[1]
         nbookmarks = source_slice.bookmarks | take_slice.bookmarks
         self.allow_missing = allow_missing
+        self.keep_missing = keep_missing
         MultiUnaryOp.__init__(self, [source_slice, take_slice], name=name, rtype=ntype, dims=take_slice.dims, bookmarks = nbookmarks)#}}}
 
 class GroupIndexOp(MultiUnaryOp):#{{{
