@@ -112,7 +112,7 @@ class Func(object):
 class UnaryFuncOp(repops.UnaryOpRep, Func):
     def __init__(self, source, *params, **kwargs):
         if(not isinstance(source, representor.Representor)):
-            source = python.Rep(source)
+            source = python.Rep(source,name="data")
         repops.UnaryOpRep.__init__(self,source, *params,**kwargs)
 
 class UnaryFuncElemOp(UnaryFuncOp):
@@ -180,9 +180,9 @@ class UnaryFuncAggregateOp(UnaryFuncDimOp):
 class BinaryFuncOp(repops.MultiOpRep, Func):
     def __init__(self, lsource, rsource, **kwargs):
         if(not isinstance(lsource, representor.Representor)):
-            lsource = repops.PlusPrefix(python.Rep(lsource))
+            lsource = repops.PlusPrefix(python.Rep(lsource,name="data"))
         if(not isinstance(rsource, representor.Representor)):
-            rsource = repops.PlusPrefix(python.Rep(rsource))
+            rsource = repops.PlusPrefix(python.Rep(rsource,name="data"))
         repops.MultiOpRep.__init__(self,(lsource,rsource), **kwargs)
 
         
@@ -221,9 +221,9 @@ class BinaryFuncElemOp(BinaryFuncOp):
                 name = binslices[0].name
             else:
                 name = "result"
-                if(not pos is None):
-                    outparam = outparam.withNumber(pos)
             outparam = Param(name, outparam)
+            if(not pos is None and name == "result"):
+                outparam = outparam.withNumber(pos)
         s = ops.BinFuncElemOp(cls.__name__, sig,outparam, **nkwargs)
         return s
 
@@ -501,6 +501,15 @@ class ReplaceMissing(UnaryFuncElemOp):
     _sigs =[repmissing]
 
 
+class IsMissingSig(FuncSignature):
+    def check(self, slice, def_value=NOVAL):#{{{
+        o_type = rtypes.TypeBool()
+        return Param(slice.name, o_type)#}}}
+ismissingsig = IsMissingSig("ismissing")
+
+class IsMissing(UnaryFuncElemOp):
+    _sigs =[ismissingsig]
+
 class UnaryFixShapeSignature(FuncSignature):
     def __init__(self,name,check_dependent=True):
         self.check_dependent = check_dependent
@@ -562,9 +571,15 @@ sortablesig = UnarySortableSignature("sortable")
 class Argsort(UnaryFuncDimOp):
     _sigs = [sortablesig]
 
+sortablesig = UnarySortableSignature("sortable")
+class Rank(UnaryFuncDimOp):
+    _sigs = [sortablesig]
+
 class Pos(UnaryFuncDimOp):
     _sigs = [any_nodepsig]
 
+class CumSum(UnaryFuncDimOp):
+    _sigs = [int_tointsig, float_tofloatsig]
 
 class Any(UnaryFuncAggregateOp):
     _sigs = [boolsig]
